@@ -80,13 +80,13 @@ enum : int {
     SBK_QtConcurrent_IDX_COUNT                               = 4
 };
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtConcurrentTypes;
+extern PyTypeObject **SbkPySide2_QtConcurrentTypes;
 
 // This variable stores the Python module object exported by this module.
-extern PyObject* SbkPySide2_QtConcurrentModuleObject;
+extern PyObject *SbkPySide2_QtConcurrentModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtConcurrentTypeConverters;
+extern SbkConverter **SbkPySide2_QtConcurrentTypeConverters;
 
 // Converter indices
 enum : int {
@@ -101,9 +101,12 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QtConcurrent::ThreadFunctionResult >() { return SbkPySide2_QtConcurrentTypes[SBK_QTCONCURRENT_THREADFUNCTIONRESULT_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QtConcurrent::ReduceOption >() { return SbkPySide2_QtConcurrentTypes[SBK_QTCONCURRENT_REDUCEOPTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QFlags<QtConcurrent::ReduceOption> >() { return SbkPySide2_QtConcurrentTypes[SBK_QFLAGS_QTCONCURRENT_REDUCEOPTION_IDX]; }
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+template<> inline PyTypeObject *SbkType< ::QtConcurrent::ThreadFunctionResult >() { return SbkPySide2_QtConcurrentTypes[SBK_QTCONCURRENT_THREADFUNCTIONRESULT_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QtConcurrent::ReduceOption >() { return SbkPySide2_QtConcurrentTypes[SBK_QTCONCURRENT_REDUCEOPTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QtConcurrent::ReduceOption> >() { return SbkPySide2_QtConcurrentTypes[SBK_QFLAGS_QTCONCURRENT_REDUCEOPTION_IDX]; }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
