@@ -202,6 +202,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QAccelerometer::AccelerationMode >() { return SbkPySide2_QtSensorsTypes[SBK_QACCELEROMETER_ACCELERATIONMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QAccelerometer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSensorsTypes[SBK_QACCELEROMETER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAccelerometerFilter >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSensorsTypes[SBK_QACCELEROMETERFILTER_IDX]); }
@@ -277,6 +279,7 @@ template<> inline PyTypeObject *SbkType< ::QTiltFilter >() { return reinterpret_
 template<> inline PyTypeObject *SbkType< ::QTiltReading >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSensorsTypes[SBK_QTILTREADING_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QTiltSensor >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSensorsTypes[SBK_QTILTSENSOR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::qoutputrange >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSensorsTypes[SBK_QOUTPUTRANGE_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
