@@ -147,6 +147,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QSql::Location >() { return SbkPySide2_QtSqlTypes[SBK_QSQL_LOCATION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSql::ParamTypeFlag >() { return SbkPySide2_QtSqlTypes[SBK_QSQL_PARAMTYPEFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QSql::ParamTypeFlag> >() { return SbkPySide2_QtSqlTypes[SBK_QFLAGS_QSQL_PARAMTYPEFLAG_IDX]; }
@@ -177,6 +179,7 @@ template<> inline PyTypeObject *SbkType< ::QSqlResult::BindingSyntax >() { retur
 template<> inline PyTypeObject *SbkType< ::QSqlResult >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSqlTypes[SBK_QSQLRESULT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSqlTableModel::EditStrategy >() { return SbkPySide2_QtSqlTypes[SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSqlTableModel >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSqlTypes[SBK_QSQLTABLEMODEL_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
